close all; clear all; clc;
% fitting of fluorescence intensity

% file input
[fname,pname] = uigetfile('*.txt','input of data');
pfname = strcat(pname,fname);
fid = fopen(pfname,'r');
% reading the file header
row1 = fgetl(fid); job_title = row1;
row2 = fgetl(fid); row3 = fgetl(fid); channels_per_curve = str2double(row3);
row4 = fgetl(fid); row5 = fgetl(fid); display_curve_no = str2double(row5);
row6 = fgetl(fid); row7 = fgetl(fid); memory_block_no = str2double(row7);
row8 = fgetl(fid); row9 = fgetl(fid); ns_channel = str2double(row9)/10000;
row10 = fgetl(fid);
% reading the main part of the file - into matrix channel
channel = fscanf(fid,'%i');
status = fclose(fid);

% displaying of values from file header
%channels_per_curve
%display_curve_no
%memory_block_no
ns_channel
%row10

% extracting the most important part of the data with the exponential decay
% determination of the data maximum and its index value (Im)
[Cm,Im] = max(channel);
% extraction
size_channel = size(channel);
channel_extract = channel(Im:size_channel);
% for next processing we need it in a form of one row matrix:
It_measured = channel_extract';

% creation of the matrix t with the time, starting from the data maximum
t = 0:ns_channel:(size(channel_extract)-1)*ns_channel;

% plotting the measured (and extracted) data
plot(t,channel_extract,'*b','MarkerSize',2);
xlabel('t [s]','FontSize',10); ylabel('Intensity [number of photones]','FontSize',10);

% FITTING
% creation of anonymous function: the exponential fitting function
ye = @(b,x) b(1).*exp(-b(2).*x);

% parameters of the starting model
starting_model = [250; 0.5]

% creation of next anonymous function:  an Ordinary Least Squares cost function
OLS = @(b) sum((ye(b,t) - It_measured).^2);

% estimation of the optimum parameters for the fminsearch() function
opts = optimset('MaxFunEvals',50000, 'MaxIter',10000);

% finding of minimum of Least Square function (fitting itself)
B = fminsearch(OLS, starting_model, opts);  %results of the fit are in matrix B

hold on
plot(t, ye(B,t), '-r')
hold off
grid
legend('measured data','fitted function');

% displaying the estimtaed parameters of the fitted function
alpha = B(1)
fluoresc_life_time = 1/B(2)


% fitting with the help of the Fitting Tool box
% f = fit(t, It_measured, 'exp1')
% alpha2 = a
% fluoresc_life_time2 = 1/b
